@@ -3,11 +3,11 @@
 
 =head1 NAME
 
-RDF::Trine::Iterator::Bindings - Stream (iterator) class for bindings query results.
+RDF::Trine::Iterator::Bindings - Stream (iterator) class for bindings query results
 
 =head1 VERSION
 
-This document describes RDF::Trine::Iterator::Bindings version 0.123
+This document describes RDF::Trine::Iterator::Bindings version 0.124
 
 =head1 SYNOPSIS
 
@@ -44,7 +44,7 @@ use base qw(RDF::Trine::Iterator);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.123';
+	$VERSION	= '0.124';
 }
 
 =item C<new ( \@results, \@names, %args )>
@@ -56,8 +56,6 @@ an reference to an array containing results or a CODE reference that
 acts as an iterator, returning successive items when called, and
 returning undef when the iterator is exhausted.
 
-$type should be one of: bindings, boolean, graph.
-
 =cut
 
 sub new {
@@ -485,7 +483,7 @@ sub as_xml {
 	return $string;
 }
 
-=item C<as_string ( $max_size )>
+=item C<as_string ( $max_size [, \$count] )>
 
 Returns a string table serialization of the stream data.
 
@@ -494,32 +492,38 @@ Returns a string table serialization of the stream data.
 sub as_string {
 	my $self			= shift;
 	my $max_result_size	= shift || 0;
+	my $rescount		= shift;
 	my @names			= $self->binding_names;
 	my $headers			= \@names;
-	my $rows			= [ map { [ @{$_}{ @names } ] } $self->get_all ];
-
+	my @rows;
+	my $count	= 0;
+	while (my $row = $self->next) {
+		push(@rows, [ map { blessed($_) ? $_->as_string : '' } @{ $row }{ @names } ]);
+		last if ($max_result_size and ++$count >= $max_result_size);
+	}
+#	my $rows			= [ map { [ map { blessed($_) ? $_->as_string : '' } @{$_}{ @names } ] } @nodes ];
+	if (ref($rescount)) {
+		$$rescount	= scalar(@rows);
+	}
+	
 	my @rule			= qw(- +);
 	my @headers			= (\q"| ");
 	push(@headers, map { $_ => \q" | " } @$headers);
 	pop	@headers;
 	push @headers => (\q" |");
 	
-	unless ('ARRAY' eq ref $rows) {
-		die("make_table() rows must be an AoA with rows being same size as headers");
-	}
-	
-	if ('ARRAY' eq ref $rows->[0]) {
-		if (@$headers == @{ $rows->[0] }) {
+	if ('ARRAY' eq ref $rows[0]) {
+		if (@$headers == @{ $rows[0] }) {
 			my $table = Text::Table->new(@headers);
 			$table->rule(@rule);
 			$table->body_rule(@rule);
-			$table->load(@$rows);
+			$table->load(@rows);
 		
 			return join('',
 					$table->rule(@rule),
 					$table->title,
 					$table->rule(@rule),
-					map({ $table->body($_) } 0 .. @$rows),
+					map({ $table->body($_) } 0 .. @rows),
 					$table->rule(@rule)
 				);
 		} else {
