@@ -7,20 +7,10 @@ RDF::Trine::Model::Dataset - Model for SPARQL datasets
 
 =head1 VERSION
 
-This document describes RDF::Trine::Model::Dataset version 0.999_02
-
-=head1 STATUS
-
-This module's API and functionality should be considered unstable.
-In the future, this module may change in backwards-incompatible ways,
-or be removed entirely. If you need functionality that this module provides,
-please L<get in touch|http://www.perlrdf.org/>.
+This document describes RDF::Trine::Model::Dataset version 0.124
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Trine::Model> class.
-
 =over 4
 
 =cut
@@ -37,7 +27,7 @@ use RDF::Trine::Model;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.999_02';
+	$VERSION	= '0.124';
 }
 
 ################################################################################
@@ -128,23 +118,6 @@ sub size {
 	return $self->count_statements( undef, undef, undef, undef );
 }
 
-=item C<< supports ( [ $feature ] ) >>
-
-If C<< $feature >> is specified, returns true if the feature is supported by the
-underlying store, false otherwise. If C<< $feature >> is not specified, returns
-a list of supported features.
-
-=cut
-
-sub supports {
-	my $self	= shift;
-	my $store	= $self->_store;
-	if ($store) {
-		return $store->supports( @_ );
-	}
-	return;
-}
-
 =item C<< count_statements ( $subject, $predicate, $object ) >>
 
 Returns a count of all the statements matching the specified subject,
@@ -345,18 +318,6 @@ sub get_pattern {
 	}
 }
 
-=item C<< get_sparql ( $sparql ) >>
-
-Returns a stream object of all bindings matching the specified graph pattern.
-
-=cut
-
-sub get_sparql {
-	my $self	= shift;
-	return $self->model->get_sparql( @_ ) unless (scalar(@{ $self->{stack} }));
-	throw RDF::Trine::Error::UnimplementedError -text => "Cannot execute SPARQL queries against a complex dataset model";
-}
-
 =item C<< get_contexts >>
 
 Returns an iterator containing the nodes representing the named graphs in the
@@ -388,7 +349,7 @@ sub model {
 
 sub _store {
 	my $self	= shift;
-	return $self->model->_store;
+	return;
 }
 
 1;
@@ -397,18 +358,13 @@ __END__
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests to through the GitHub web interface
-at L<https://github.com/kasei/perlrdf/issues>.
-
 =head1 AUTHOR
 
 Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2012 Gregory Todd Williams. This
+Copyright (c) 2006-2010 Gregory Todd Williams. All rights reserved. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
