@@ -3,11 +3,11 @@
 
 =head1 NAME
 
-RDF::Trine::Parser::NQuads - N-Quads Parser.
+RDF::Trine::Parser::NQuads - N-Quads Parser
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser::NQuads version 0.123
+This document describes RDF::Trine::Parser::NQuads version 0.124
 
 =head1 SYNOPSIS
 
@@ -48,7 +48,7 @@ use RDF::Trine::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.123';
+	$VERSION	= '0.124';
 	$RDF::Trine::Parser::parser_names{ 'nquads' }	= __PACKAGE__;
 # 	foreach my $type (qw(text/plain)) {
 # 		$RDF::Trine::Parser::media_types{ $type }	= __PACKAGE__;
