@@ -4,7 +4,7 @@ RDF::Trine::Store::Hexastore - RDF store implemented with the hexastore index
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::Hexastore version 0.123
+This document describes RDF::Trine::Store::Hexastore version 0.124
 
 =head1 SYNOPSIS
 
@@ -43,8 +43,9 @@ use constant OTHERNODES	=> {
 
 our $VERSION;
 BEGIN {
-	$VERSION	= "0.123";
-	$RDF::Trine::Store::STORE_CLASSES{ __PACKAGE__ }	= $VERSION;
+	$VERSION	= "0.124";
+	my $class	= __PACKAGE__;
+	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
 }
 
 ######################################################################
@@ -72,6 +73,14 @@ sub new {
 	return $self;
 }
 
+sub _new_with_string {
+    my ($self, $config) = @_;
+    my ($filename) = $config =~ m/file=(.+)$/; # TODO: It has a Storable part too, for later use.
+    return $self->load($filename);
+}
+
+
+
 =item C<< store ( $filename ) >>
 
 Write the triples data to a file specified by C<< $filename >>.
